# Installation

Install GitEase with pip: `pip install gitease`

If you want AI to write your commits for you:

1. Get an [openai api key](https://platform.openai.com/account/api-keys) and set it up.
2. Set environment variable: `export OPENAI_API_KEY_NAME=...`